---
feature_story: FS_24_50_40_64
feature_title: arg types without envelope classes
feature_status: TEST
---

Some arg types do not have meaningful associated `data_envelope`.

For example, `AccessType` (`ro` or `rw`) - it is just a mode of operation
(and has nothing to do with target `data_envelope`).

To keep reusing the same suggestion mechanism,
it is easier to create surrogate as many `data_envelope` with `envelope_class` = `AccessType`
as there are discrete arg values within that arg type (2, in case of `AccessType`: `ro` and `rw`).
